import { select, 
        scaleOrdinal,
        schemeRdYlGn
        } from 'd3';
import { feature } from 'topojson';
import { loadAndProcessData } from './loadAndProcessData.js';
import { colorLegend } from './colorLegend.js';
import { chloroplethMap } from './chloroplethMap.js';

const width = document.body.clientWidth;
const height = document.body.clientHeight;

const svg = select('svg');
const chloroplethMapG = svg.append('g');
const colorLegendG = svg.append('g')
	.attr('transform', `translate(50,250)`)

const colorScale = scaleOrdinal();
const colorValue = d => d.properties.economy

let selectedColorValue;
let features;

const onClick = d => {
	selectedColorValue = d;
  render();
};

loadAndProcessData().then(countries => {
  features = countries.features;
  render();
});

const render = () => {
	colorScale
    .domain(features.map(colorValue))
  	.domain(colorScale.domain().sort().reverse())
  	.range(schemeRdYlGn[colorScale.domain().length]);
  
  colorLegendG
  	.call(colorLegend, {
      colorScale,
      spacing: 30,
      circleRadius: 10,
      textOffset: 20,
    	onClick,
    	selectedColorValue
  });
  
  chloroplethMapG
  	.call(chloroplethMap, {
  		features,
    	colorScale,
    	colorValue,
    	selectedColorValue
  })
};